'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var useIntl = require('use-intl');
var Link = require('next/link');
var React = require('react');
var router = require('next/router');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var Link__default = /*#__PURE__*/_interopDefaultLegacy(Link);
var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var _excluded$1 = ["href", "locale"];
function createLocalizedLinkComponent(useLocale) {
  /**
   * Wraps `next/link` and prefixes the `href` with the current locale.
   */
  function LocalizedLink(_ref, ref) {
    var href = _ref.href,
        locale = _ref.locale,
        rest = _objectWithoutPropertiesLoose(_ref, _excluded$1);

    var curLocale = useLocale();
    if (!locale) locale = curLocale;
    var localizedHref = '/' + locale;

    if (href !== '/') {
      localizedHref += href;
    }

    return React__default["default"].createElement(Link__default["default"], _extends({
      ref: ref,
      href: localizedHref
    }, rest));
  }

  return React.forwardRef(LocalizedLink);
}

// Reuse the legacy cookie name
// https://nextjs.org/docs/advanced-features/i18n-routing#leveraging-the-next_locale-cookie
var COOKIE_LOCALE_NAME = 'NEXT_LOCALE';

/**
 * This is necessary so the middleware only has to match
 * on the root path, but we can keep the cookie in sync.
 */

function useCookieSync(locale) {
  React.useEffect(function () {
    var _cookie$split;

    var cookie = document.cookie.split(';').find(function (cur) {
      return cur.includes(COOKIE_LOCALE_NAME + '=');
    });
    var prevLocale = cookie == null ? void 0 : (_cookie$split = cookie.split('=')) == null ? void 0 : _cookie$split[1];

    if (prevLocale !== locale) {
      document.cookie = COOKIE_LOCALE_NAME + "=" + locale + "; path=/; expires=Fri, 31 Dec 9999 23:59:59 GMT";
    }
  }, [locale]);
}

var _excluded = ["children", "locale"];
function NextIntlClientProvider(_ref) {
  var children = _ref.children,
      locale = _ref.locale,
      rest = _objectWithoutPropertiesLoose(_ref, _excluded);

  var router$1;

  try {
    // Reading from context is practically ok to do conditionally
    // eslint-disable-next-line react-hooks/rules-of-hooks
    router$1 = router.useRouter();
  } catch (error) {// Calling `useRouter` is not supported in the app folder
  } // The router can be undefined if used in a context outside
  // of Next.js (e.g. unit tests, Storybook, ...)


  if (!locale && router$1) {
    locale = router$1.locale;
  }

  if (!locale) {
    throw new Error("Couldn't determine locale. Please pass an explicit `locale` prop the provider, or if you're using the `pages` folder, use internationalized routing (https://nextjs.org/docs/advanced-features/i18n-routing)." );
  }

  useCookieSync(locale);
  return React__default["default"].createElement(useIntl.IntlProvider, _extends({
    locale: locale
  }, rest), children);
}

var LocalizedLink = /*#__PURE__*/createLocalizedLinkComponent(useIntl.useLocale); // Legacy export for compatibility

exports.LocalizedLink = LocalizedLink;
exports.NextIntlProvider = NextIntlClientProvider;
Object.keys(useIntl).forEach(function (k) {
  if (k !== 'default' && !exports.hasOwnProperty(k)) Object.defineProperty(exports, k, {
    enumerable: true,
    get: function () { return useIntl[k]; }
  });
});
//# sourceMappingURL=next-intl.cjs.development.js.map
