import Link from 'next/link';
import React, { forwardRef } from 'react';
export default function createLocalizedLinkComponent(useLocale) {
    /**
     * Wraps `next/link` and prefixes the `href` with the current locale.
     */
    function LocalizedLink({ href, locale, ...rest }, ref) {
        const curLocale = useLocale();
        if (!locale)
            locale = curLocale;
        let localizedHref = '/' + locale;
        if (href !== '/') {
            localizedHref += href;
        }
        return React.createElement(Link, { ref: ref, href: localizedHref, ...rest });
    }
    return forwardRef(LocalizedLink);
}
//# sourceMappingURL=createLocalizedLinkComponent.js.map